#
# spec file for package kf6-extra-cmake-modules
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor doc%{nil}
%if "%{flavor}" == "doc"
%global pkg_suffix -doc
%endif

%define rname extra-cmake-modules

# Full KF6 version (e.g. 6.15.0)
%{!?_kf6_version: %global _kf6_version %{version}}
%bcond_without doc
%bcond_without released
Name:           kf6-extra-cmake-modules%{?pkg_suffix}
Version:        6.15.0
Release:        1.1
Summary:        CMake modules
License:        BSD-3-Clause
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  cmake >= 3.16
%if 0%{?suse_version} > 1500
BuildRequires:  gcc-c++
%else
BuildRequires:  gcc13-c++
BuildRequires:  gcc13-PIE
%endif
BuildRequires:  kf6-filesystem
%if "%{flavor}" != "doc"
Requires:       cmake >= 3.16
%if 0%{?suse_version} > 1500
Requires:       gcc-c++
%else
Requires:       gcc13-c++
Requires:       gcc13-PIE
%endif
# kf6-extra-cmake-modules is used to build both kf5 and kf6 based packages
# it has to require the resp. -filesystem package
Requires:       kf5-filesystem
Requires:       kf6-filesystem
Recommends:     kf6-extra-cmake-modules-doc
Provides:       extra-cmake-modules = %{version}
Obsoletes:      extra-cmake-modules < %{version}
%else
BuildRequires:  python3-Sphinx
Provides:       extra-cmake-modules-doc = %{version}
Obsoletes:      extra-cmake-modules-doc < %{version}
%endif
BuildArch:      noarch

%description
Extra modules and scripts for CMake.
%if "%{flavor}" == "doc"

This package provides documentation for kf6-extra-cmake-modules
%endif

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%if "%{flavor}" == "doc"
rm -r %{buildroot}%{_datadir}/ECM
%endif

%files
%if "%{flavor}" != "doc"
%license LICENSES/*
%{_datadir}/ECM/
%else
%doc %{_datadir}/doc/ECM/
%doc %lang(en) %{_mandir}/man7/ecm*.7*
%endif

%changelog
* Mon Jun  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.15.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.15.0
- Changes since 6.14.0:
  * [ECMGenerateQDoc] Don't put qch file in target subfolder
  * Fix LOCALSTATEDIR when installing to /usr (kde#505090)
  * [ECMGenerateQDoc] Fix locations for generated HTML files
  * ECMGeneratePythonBindings: Check if the build python module is installed
  * Tone done warning about existing .clang-format file
  * [ECMGenerateQDoc] Use combined output dir for all targets
  * Add timestamp to filenames of APKs built on CI
  * ECMGeneratePythonBindings: remove another deprecation macro since pyside/shiboken uses deprecated code
  * kde-modules/clang-format.cmake - add support for Json files (kde#503056)
  * [ECMGenerateQDoc] Handle qhelpgenerator tool not being found
  * [ECMGenerateQDoc] Handle qdoc tool not being found
  * Update version to 6.15.0
- Replace _kf6_bugfix_version usage
* Sun May  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.14.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.14.0
- Changes since 6.13.0:
  * Update dependency version to 6.14.0
  * ECMGeneratePythonBindings: install typesystem XML file to CMAKE_INSTALL_PREFIX
  * ECMGeneratePythonBindings: add `EXPORT_TYPESYSTEM` to install typesystem file
* Sat Apr  5 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.13.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.13.0
- Changes since 6.12.0:
  * Add missing include mocs
  * ECMAddTests.cmake: add support to pass environment variables and compile definitions
  * tests: Fix cmake deprecation warning
  * ECMEnableSanitizers.cmake: replace tabs with spaces
  * KDECompilerSettings: default to C++20 for level 6.13
  * ECMEnableSanitizers.cmake: fix GCC's "note: variable tracking size limit exceeded" when using asan
  * Update dependency version to 6.13.0
* Tue Mar 11 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.12.0
- Changes since 6.11.0:
  * Consider BSL-1.0 as GPL-compatible
  * Improve docs for ECM QML modules
  * Drop old > 2 cmake version conditional branch
  * Require cmake >= 3.16 for the tests too.
  * Add tests for KDE_INSTALL_APP_TEMPLATES.
  * Unless setting KDE_INSTALL_APP_TEMPLATES, kde_package_app_templates is skipped when cross-compiling.
  * Try to also satisfy Google Play's version code constraints
  * Generate Gradle version include file as part of ecm_add_android_apk()
  * Update version to 6.12.0
* Sat Feb  8 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.11.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.11.0
- Changes since 6.10.0:
  * Fix FindEGL compile check when using Emscripten
  * Add xml/yaml linting
  * ECMAddAndroidApk.cmake: use APK_NAME for APK_OUTPUT_DIR
  * Add ECMGenerateQDoc
  * CI: Add linux-qt6-next build
  * ECMQmLoader.cpp.in: Use qAsConst instead of std::as_const in Qt5 codepath
  * Lower Python requirement to 3.9
  * ECMQmLoader.cpp.in: Add std::as_const for enhanced for loop
  * Update version to 6.11.0
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * Make building docs optional
  * Add since documentation
  * ECMAddAndroidApk: add "PACKAGE_NAME" argument
  * ECMGenerateHeaders: set IWYU export pragma also for helper prefixed headers
  * Also allow to disable the nasty Android threads workaround via env vars
  * ECMGenerateHeaders: Set include-what-you-use pragma
  * Simplify moving QM catalog loading to the main thread
  * Update version to 6.10.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Align multi-language catalog loading with KI18n
  * EGPF: Handle case where INTERFACE_INCLUDE_DIRECTORIES is empty (kde#496781)
  * KDEClangFormat: Avoid spammy warnings with cmake >= 3.31.0 (kde#496537)
  * Consider all QLocale::uiLanguages for QM catalog loading
  * ECMGeneratePythonBindings: Build without system isolation
  * ECMGeneratePythonBindings: Remove broken RPATH settings
  * Include Qt's translations in what we bundle on Android
  * Fix FindLibMount without pkgconfig
  * Don't use KDEInstallDirs6 for the new ECMGeneratePkgConfigFile test
  * Fix reproducible build issue with ECMGeneratedHeaders
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * FindKF6: Print custom message when required components are not found
  * Add a directory check when appending a module dir to qmlimportscanner
  * Add Python bindings
  * Break enums onto multiple lines
  * Set import paths for QML modules to all CMake search paths
  * Remove the old/unused SIP-based Python binding generation infrastructure
  * Update version to 6.8.0
  * ECMGeneratePkgConfigFile: try to deduce additional include dirs
  * Fix custom definitions for generated pkgconfig files
  * Fix QM loader unit tests with a static Qt
  * Don't fall back to qmlplugin dump on static Qt builds
  * Retire Qt5 Android CI
  * Automatically install dependent targets of QML modules in static builds
  * Allow to specify an export set for targets installed by finalize_qml_module
  * Don't check websites in Appstream tests
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Merge output targets from multiple qt6_target_qml_sources() calls
  * Don't install QML files on Android
  * Propagate OUTPUT_TARGETS of qt6_target_qml_sources to the caller
  * Port Qt doc generation to qhelpgenerator
  * Correctly forward the OUTPUT_TARGETS argument of qt6_add_qml_module()
  * Set install destination for object files
  * Upstream FindGLIB2.cmake changes from Qt
  * KDEClangFormat: Ignore source files being in _install folder
  * reenable individual targets for clang-format to enable better status reporting an parallelization
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * ECMQueryQt: don't cache QUERY_EXECUTABLE
  * Add fallback value for SASL_PATH
  * Add SASL_PATH to prefix.sh so that libkdexoauth2.so is found
  * Allow qml target to be actually optional
  * Fix FindLibExiv2 version detection from header
  * ci: add Alpine/musl job
  * ECMEnableSanitizers: fix greedy linker parameter replacment
  * Add private code option to ecm_add_qtwayland_(client/server)_protocol
  * Update version to 6.6.0
  * Add a PRIVATE_CODE option to ecm_add_wayland_server_protocol
  * Add [PRIVATE_CODE] also to the second signature of ecm_add_wayland_server_protocol
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * prefix.sh.cmake add MANPATH
  * Update version to 6.5.0
  * FindWaylandScanner: Add flag to use private-code
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * Avoid spurious message about appstreamtest
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * Skip app template packaging when cross-compiling
  * Remove explicit maintainer from metainfo
  * ECMQueryQt: Provide better error message when Qt6 qpaths is not found
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * API dox: KDEInstallDirs6: refer to qtpaths now as source of Qt paths
  * API dox: KDEInstallDirs6: drop outdated note about being in ALPHA state
  * test: Increase minimum cmake version so that it works with Qt 6.7
  * ECMQmlModule6: group qml and resource file calls
  * modules/ECMAddTests.cmake - handle unset or empty QT_PLUGIN_PATH
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * ECMAddQch: drop trying to set IMPORTED on targets with installed config
  * Fix DATAROOTDIR documentation for Windows
  * Update documentation favicon
  * macOS is the name of the Apple operating system
  * Fix fetch translations tests in GitLab forks
  * docs: Correct escape sequence for Python 3.12 or later
  * Map some more language codes to the IDs supported by Google Play
  * [ECMQmlModule] Add option to enable verbose compiler output
  * Remove extraneous docs-build CI job that is no longer needed following
    the switch of api.kde.org to Gitlab CI
  * Set ECM_PREFIX at build time rather than at runtime (kde#485158)
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * Filter out Asturian and Esperanto
  * Revert "Interlingua is now supported by Android"
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Wed Jan 31 2024 Christophe Marin <christophe@krop.fr>
- Switch to the latest GCC version available in Leap for packages
  that can't build with the default compiler
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
  * https://kde.org/announcements/megarelease/6/rc1/
* Tue May 30 2023 Christophe Marin <christophe@krop.fr>
- Swith to gcc12 for Leap builds. Some frameworks fail to build
  with gcc10.
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-extra-cmake-modules
